phoneapp/phoneuiutils/inc/tphonecmdparamtranseffect.h
branchRCL_3
changeset 62 5266b1f337bd
parent 61 41a7f70b3818
child 69 8baf28733c3d
--- a/phoneapp/phoneuiutils/inc/tphonecmdparamtranseffect.h	Tue Aug 31 15:14:29 2010 +0300
+++ b/phoneapp/phoneuiutils/inc/tphonecmdparamtranseffect.h	Wed Sep 01 12:30:10 2010 +0100
@@ -37,21 +37,29 @@
 enum TPhoneTransEffectType
     {
     EPhoneTransEffectNone,
+    EPhoneTransEffectCallUiAppear,
+    EPhoneTransEffectCallUiDisappear,
+    // These 3 effect types can be used only when dialer is
+    // opened/closed when some other app than phone is visible 
+    // on the foreground/in the background.
+    // These cannot be used for internal transitions (=call ui<->dialer).
     EPhoneTransEffectDialerOpen,
     EPhoneTransEffectDialerClose,
     EPhoneTransEffectDialerCreate,
+    // For applying effect to external app launch done from dialer.
+    // Effects triggered by App FW don't work properly.
+    EPhoneTransEffectAppStartFromDialer,
     EPhoneTransEffectStop
     };
 
 // CLASS DECLARATION
 
 /**
 *  A parameter class for note dialog information.
 */
 class TPhoneCmdParamTransEffect : public TPhoneUICommandParam
     {   
-   
-    
+
     public: 
            
         /**
@@ -67,19 +75,37 @@
         */
         IMPORT_C void SetType( TPhoneTransEffectType aType );
 
- 
+        /**
+        * Sets application uid associated with the effect.
+        * @param    aAppUid, Id of app.
+        * @return   None.
+        */
+        IMPORT_C void SetAppUid( const TUid& aAppUid );
+
         /**
         * Returns the effect type
         * @return Returns the type
         */
         IMPORT_C TPhoneTransEffectType Type() const;
-   
+
+        /**
+        * Returns App uid associated with the effect.
+        * @param    None.
+        * @return   iAppUid.
+        */
+        IMPORT_C TUid AppUid() const;
+
     private:    
         
         /**
-        * Note type
+        * Effect type
         */
         TPhoneTransEffectType iType;
+        
+        /**
+        * App UID
+        */
+        TUid iAppUid;
 
     };
@@ -37,21 +37,29 @@
 
 /**
-*  A parameter class for note dialog information.
+*  A parameter class for transition effect information.
 */
 class TPhoneCmdParamTransEffect : public TPhoneUICommandParam